/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FullStarter.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.starterfull;

import java.io.File;

import org.ow2.jonas.autostart.configuration.Configuration;
import org.ow2.jonas.autostart.configurator.Configurator;
import org.ow2.jonas.autostart.starter.Starter;
import org.ow2.jonas.autostart.utility.Output;

/**
 * This class starts JOnAS server.
 * @author skabore
 */
public class FullStarter extends Starter {

    /**
     * The file separator.
     */
    private static final String FILE_SEPARATOR = System.getProperty("file.separator");

    /**
     * The configuration.
     */
    private Configuration configuration;

    /**
     * Build a new Starter with default output stream..
     */
    public FullStarter() {
        super();
    }

    /**
     * Build a new Starter.
     * @param output the output stream.
     */
    public FullStarter(final Output output) {
        super(output);
    }

    /**
     * Configures the JOnAS server.
     */
    public void applyReconfiguration() {
        if (getJonasBase() == null && getJonasBaseInstallLocation() != null) {
            setJonasBase(new File(getJonasBaseInstallLocation().getAbsolutePath() + FILE_SEPARATOR + getJonasBaseFolder()));
        }
        if (getJonasBase() != null) {
            Configurator configurator = new Configurator(getJonasRoot().getAbsolutePath(), getJonasBase().getAbsolutePath(),
                    configuration, getWorkdirectory());
            configurator.doConfiguration();
        }
    }

    /**
     * @return configuration
     */
    public Configuration getConfiguration() {
        return configuration;
    }

    /**
     * Set the configuration.
     * @param configuration the configuration.
     */
    public void setConfiguration(final Configuration configuration) {
        this.configuration = configuration;
    }
}
